# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DashboardGroup(object):
    """
    The base schema for a dashboard group.
    """

    #: A constant which can be used with the lifecycle_state property of a DashboardGroup.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DashboardGroup.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DashboardGroup.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DashboardGroup.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DashboardGroup.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DashboardGroup.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DashboardGroup object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DashboardGroup.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this DashboardGroup.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DashboardGroup.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DashboardGroup.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this DashboardGroup.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DashboardGroup.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DashboardGroup.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DashboardGroup.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DashboardGroup.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DashboardGroup.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DashboardGroup.
        The `OCID`__ of the dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this DashboardGroup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DashboardGroup.
        The `OCID`__ of the dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this DashboardGroup.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DashboardGroup.
        A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information.
        Leading and trailing spaces and the following special characters are not allowed: <>()=/'\"&\\


        :return: The display_name of this DashboardGroup.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DashboardGroup.
        A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information.
        Leading and trailing spaces and the following special characters are not allowed: <>()=/'\"&\\


        :param display_name: The display_name of this DashboardGroup.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this DashboardGroup.
        A short description of the dashboard group. It can be changed. Avoid entering confidential information.
        The following special characters are not allowed: <>()=/'\"&\\


        :return: The description of this DashboardGroup.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DashboardGroup.
        A short description of the dashboard group. It can be changed. Avoid entering confidential information.
        The following special characters are not allowed: <>()=/'\"&\\


        :param description: The description of this DashboardGroup.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DashboardGroup.
        The `OCID`__ of the compartment containing the dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DashboardGroup.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DashboardGroup.
        The `OCID`__ of the compartment containing the dashboard group.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DashboardGroup.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DashboardGroup.
        The date and time the dashboard group was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this DashboardGroup.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DashboardGroup.
        The date and time the dashboard group was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this DashboardGroup.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this DashboardGroup.
        The date and time the dashboard group was updated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this DashboardGroup.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DashboardGroup.
        The date and time the dashboard group was updated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this DashboardGroup.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DashboardGroup.
        The current state of the `DashboardGroup` resource.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DashboardGroup.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DashboardGroup.
        The current state of the `DashboardGroup` resource.


        :param lifecycle_state: The lifecycle_state of this DashboardGroup.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        **[Required]** Gets the freeform_tags of this DashboardGroup.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DashboardGroup.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DashboardGroup.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DashboardGroup.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        **[Required]** Gets the defined_tags of this DashboardGroup.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DashboardGroup.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DashboardGroup.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DashboardGroup.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DashboardGroup.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DashboardGroup.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DashboardGroup.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DashboardGroup.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .record_metadata import RecordMetadata
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImageMetadata(RecordMetadata):
    """
    Collection of metadata related to image record.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImageMetadata object with values from keyword arguments. The default value of the :py:attr:`~oci.data_labeling_service_dataplane.models.ImageMetadata.record_type` attribute
        of this class is ``IMAGE_METADATA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param record_type:
            The value to assign to the record_type property of this ImageMetadata.
            Allowed values for this property are: "IMAGE_METADATA", "TEXT_METADATA", "DOCUMENT_METADATA"
        :type record_type: str

        :param height:
            The value to assign to the height property of this ImageMetadata.
        :type height: int

        :param width:
            The value to assign to the width property of this ImageMetadata.
        :type width: int

        :param depth:
            The value to assign to the depth property of this ImageMetadata.
        :type depth: int

        """
        self.swagger_types = {
            'record_type': 'str',
            'height': 'int',
            'width': 'int',
            'depth': 'int'
        }

        self.attribute_map = {
            'record_type': 'recordType',
            'height': 'height',
            'width': 'width',
            'depth': 'depth'
        }

        self._record_type = None
        self._height = None
        self._width = None
        self._depth = None
        self._record_type = 'IMAGE_METADATA'

    @property
    def height(self):
        """
        Gets the height of this ImageMetadata.
        Height of the image record.


        :return: The height of this ImageMetadata.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this ImageMetadata.
        Height of the image record.


        :param height: The height of this ImageMetadata.
        :type: int
        """
        self._height = height

    @property
    def width(self):
        """
        Gets the width of this ImageMetadata.
        Width of the image record.


        :return: The width of this ImageMetadata.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this ImageMetadata.
        Width of the image record.


        :param width: The width of this ImageMetadata.
        :type: int
        """
        self._width = width

    @property
    def depth(self):
        """
        Gets the depth of this ImageMetadata.
        Depth of the image record.


        :return: The depth of this ImageMetadata.
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """
        Sets the depth of this ImageMetadata.
        Depth of the image record.


        :param depth: The depth of this ImageMetadata.
        :type: int
        """
        self._depth = depth

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CredentialAuthenticatorInfo(object):
    """
    CredentialAuthenticatorInfo model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CredentialAuthenticatorInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param raw_credential:
            The value to assign to the raw_credential property of this CredentialAuthenticatorInfo.
        :type raw_credential: str

        :param user_id:
            The value to assign to the user_id property of this CredentialAuthenticatorInfo.
        :type user_id: str

        :param tenant_id:
            The value to assign to the tenant_id property of this CredentialAuthenticatorInfo.
        :type tenant_id: str

        :param user_name:
            The value to assign to the user_name property of this CredentialAuthenticatorInfo.
        :type user_name: str

        :param tenant_name:
            The value to assign to the tenant_name property of this CredentialAuthenticatorInfo.
        :type tenant_name: str

        :param credential_identifier:
            The value to assign to the credential_identifier property of this CredentialAuthenticatorInfo.
        :type credential_identifier: str

        :param credential_list:
            The value to assign to the credential_list property of this CredentialAuthenticatorInfo.
        :type credential_list: list[str]

        :param service:
            The value to assign to the service property of this CredentialAuthenticatorInfo.
        :type service: str

        :param client_id:
            The value to assign to the client_id property of this CredentialAuthenticatorInfo.
        :type client_id: str

        """
        self.swagger_types = {
            'raw_credential': 'str',
            'user_id': 'str',
            'tenant_id': 'str',
            'user_name': 'str',
            'tenant_name': 'str',
            'credential_identifier': 'str',
            'credential_list': 'list[str]',
            'service': 'str',
            'client_id': 'str'
        }

        self.attribute_map = {
            'raw_credential': 'rawCredential',
            'user_id': 'userId',
            'tenant_id': 'tenantId',
            'user_name': 'userName',
            'tenant_name': 'tenantName',
            'credential_identifier': 'credentialIdentifier',
            'credential_list': 'credentialList',
            'service': 'service',
            'client_id': 'clientId'
        }

        self._raw_credential = None
        self._user_id = None
        self._tenant_id = None
        self._user_name = None
        self._tenant_name = None
        self._credential_identifier = None
        self._credential_list = None
        self._service = None
        self._client_id = None

    @property
    def raw_credential(self):
        """
        **[Required]** Gets the raw_credential of this CredentialAuthenticatorInfo.
        The raw credential.


        :return: The raw_credential of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._raw_credential

    @raw_credential.setter
    def raw_credential(self, raw_credential):
        """
        Sets the raw_credential of this CredentialAuthenticatorInfo.
        The raw credential.


        :param raw_credential: The raw_credential of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._raw_credential = raw_credential

    @property
    def user_id(self):
        """
        **[Required]** Gets the user_id of this CredentialAuthenticatorInfo.
        The id of the user.


        :return: The user_id of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this CredentialAuthenticatorInfo.
        The id of the user.


        :param user_id: The user_id of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._user_id = user_id

    @property
    def tenant_id(self):
        """
        **[Required]** Gets the tenant_id of this CredentialAuthenticatorInfo.
        The id of the tenant.


        :return: The tenant_id of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this CredentialAuthenticatorInfo.
        The id of the tenant.


        :param tenant_id: The tenant_id of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def user_name(self):
        """
        **[Required]** Gets the user_name of this CredentialAuthenticatorInfo.
        The name of the user.


        :return: The user_name of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this CredentialAuthenticatorInfo.
        The name of the user.


        :param user_name: The user_name of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._user_name = user_name

    @property
    def tenant_name(self):
        """
        **[Required]** Gets the tenant_name of this CredentialAuthenticatorInfo.
        The name of the tenant.


        :return: The tenant_name of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """
        Sets the tenant_name of this CredentialAuthenticatorInfo.
        The name of the tenant.


        :param tenant_name: The tenant_name of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._tenant_name = tenant_name

    @property
    def credential_identifier(self):
        """
        **[Required]** Gets the credential_identifier of this CredentialAuthenticatorInfo.
        The credential identifier.


        :return: The credential_identifier of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._credential_identifier

    @credential_identifier.setter
    def credential_identifier(self, credential_identifier):
        """
        Sets the credential_identifier of this CredentialAuthenticatorInfo.
        The credential identifier.


        :param credential_identifier: The credential_identifier of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._credential_identifier = credential_identifier

    @property
    def credential_list(self):
        """
        **[Required]** Gets the credential_list of this CredentialAuthenticatorInfo.
        The credential list.


        :return: The credential_list of this CredentialAuthenticatorInfo.
        :rtype: list[str]
        """
        return self._credential_list

    @credential_list.setter
    def credential_list(self, credential_list):
        """
        Sets the credential_list of this CredentialAuthenticatorInfo.
        The credential list.


        :param credential_list: The credential_list of this CredentialAuthenticatorInfo.
        :type: list[str]
        """
        self._credential_list = credential_list

    @property
    def service(self):
        """
        **[Required]** Gets the service of this CredentialAuthenticatorInfo.
        The name of the service that is making this authorization request.


        :return: The service of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this CredentialAuthenticatorInfo.
        The name of the service that is making this authorization request.


        :param service: The service of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._service = service

    @property
    def client_id(self):
        """
        **[Required]** Gets the client_id of this CredentialAuthenticatorInfo.
        The id of the client.


        :return: The client_id of this CredentialAuthenticatorInfo.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this CredentialAuthenticatorInfo.
        The id of the client.


        :param client_id: The client_id of this CredentialAuthenticatorInfo.
        :type: str
        """
        self._client_id = client_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VirtualService(object):
    """
    This resource represents a customer-managed service in the Service Mesh. Each virtual service declares multiple running versions of the service and maps to a group of instances/pods running a specific version of the actual service.
    """

    #: A constant which can be used with the lifecycle_state property of a VirtualService.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a VirtualService.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a VirtualService.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a VirtualService.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a VirtualService.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a VirtualService.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new VirtualService object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VirtualService.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this VirtualService.
        :type compartment_id: str

        :param mesh_id:
            The value to assign to the mesh_id property of this VirtualService.
        :type mesh_id: str

        :param name:
            The value to assign to the name property of this VirtualService.
        :type name: str

        :param description:
            The value to assign to the description property of this VirtualService.
        :type description: str

        :param default_routing_policy:
            The value to assign to the default_routing_policy property of this VirtualService.
        :type default_routing_policy: oci.service_mesh.models.DefaultVirtualServiceRoutingPolicy

        :param hosts:
            The value to assign to the hosts property of this VirtualService.
        :type hosts: list[str]

        :param mtls:
            The value to assign to the mtls property of this VirtualService.
        :type mtls: oci.service_mesh.models.MutualTransportLayerSecurity

        :param time_created:
            The value to assign to the time_created property of this VirtualService.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this VirtualService.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VirtualService.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this VirtualService.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this VirtualService.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this VirtualService.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this VirtualService.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'mesh_id': 'str',
            'name': 'str',
            'description': 'str',
            'default_routing_policy': 'DefaultVirtualServiceRoutingPolicy',
            'hosts': 'list[str]',
            'mtls': 'MutualTransportLayerSecurity',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'mesh_id': 'meshId',
            'name': 'name',
            'description': 'description',
            'default_routing_policy': 'defaultRoutingPolicy',
            'hosts': 'hosts',
            'mtls': 'mtls',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._compartment_id = None
        self._mesh_id = None
        self._name = None
        self._description = None
        self._default_routing_policy = None
        self._hosts = None
        self._mtls = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VirtualService.
        Unique identifier that is immutable on creation.


        :return: The id of this VirtualService.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VirtualService.
        Unique identifier that is immutable on creation.


        :param id: The id of this VirtualService.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this VirtualService.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this VirtualService.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this VirtualService.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this VirtualService.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def mesh_id(self):
        """
        **[Required]** Gets the mesh_id of this VirtualService.
        The OCID of the service mesh in which this virtual service is created.


        :return: The mesh_id of this VirtualService.
        :rtype: str
        """
        return self._mesh_id

    @mesh_id.setter
    def mesh_id(self, mesh_id):
        """
        Sets the mesh_id of this VirtualService.
        The OCID of the service mesh in which this virtual service is created.


        :param mesh_id: The mesh_id of this VirtualService.
        :type: str
        """
        self._mesh_id = mesh_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this VirtualService.
        A user-friendly name. The name has to be unique within the same service mesh and cannot be changed after creation.
        Avoid entering confidential information.

        Example: `My unique resource name`


        :return: The name of this VirtualService.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VirtualService.
        A user-friendly name. The name has to be unique within the same service mesh and cannot be changed after creation.
        Avoid entering confidential information.

        Example: `My unique resource name`


        :param name: The name of this VirtualService.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this VirtualService.
        Description of the resource. It can be changed after creation.
        Avoid entering confidential information.

        Example: `This is my new resource`


        :return: The description of this VirtualService.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this VirtualService.
        Description of the resource. It can be changed after creation.
        Avoid entering confidential information.

        Example: `This is my new resource`


        :param description: The description of this VirtualService.
        :type: str
        """
        self._description = description

    @property
    def default_routing_policy(self):
        """
        Gets the default_routing_policy of this VirtualService.

        :return: The default_routing_policy of this VirtualService.
        :rtype: oci.service_mesh.models.DefaultVirtualServiceRoutingPolicy
        """
        return self._default_routing_policy

    @default_routing_policy.setter
    def default_routing_policy(self, default_routing_policy):
        """
        Sets the default_routing_policy of this VirtualService.

        :param default_routing_policy: The default_routing_policy of this VirtualService.
        :type: oci.service_mesh.models.DefaultVirtualServiceRoutingPolicy
        """
        self._default_routing_policy = default_routing_policy

    @property
    def hosts(self):
        """
        Gets the hosts of this VirtualService.
        The DNS hostnames of the virtual service that is used by its callers.
        Wildcard hostnames are supported in the prefix form.
        Examples of valid hostnames are \"www.example.com\", \"*.example.com\", \"*.com\".
        Can be omitted if the virtual service will only have TCP virtual deployments.


        :return: The hosts of this VirtualService.
        :rtype: list[str]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """
        Sets the hosts of this VirtualService.
        The DNS hostnames of the virtual service that is used by its callers.
        Wildcard hostnames are supported in the prefix form.
        Examples of valid hostnames are \"www.example.com\", \"*.example.com\", \"*.com\".
        Can be omitted if the virtual service will only have TCP virtual deployments.


        :param hosts: The hosts of this VirtualService.
        :type: list[str]
        """
        self._hosts = hosts

    @property
    def mtls(self):
        """
        Gets the mtls of this VirtualService.

        :return: The mtls of this VirtualService.
        :rtype: oci.service_mesh.models.MutualTransportLayerSecurity
        """
        return self._mtls

    @mtls.setter
    def mtls(self, mtls):
        """
        Sets the mtls of this VirtualService.

        :param mtls: The mtls of this VirtualService.
        :type: oci.service_mesh.models.MutualTransportLayerSecurity
        """
        self._mtls = mtls

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this VirtualService.
        The time when this resource was created in an RFC3339 formatted datetime string.


        :return: The time_created of this VirtualService.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this VirtualService.
        The time when this resource was created in an RFC3339 formatted datetime string.


        :param time_created: The time_created of this VirtualService.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this VirtualService.
        The time when this resource was updated in an RFC3339 formatted datetime string.


        :return: The time_updated of this VirtualService.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this VirtualService.
        The time when this resource was updated in an RFC3339 formatted datetime string.


        :param time_updated: The time_updated of this VirtualService.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this VirtualService.
        The current state of the Resource.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this VirtualService.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VirtualService.
        The current state of the Resource.


        :param lifecycle_state: The lifecycle_state of this VirtualService.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this VirtualService.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.


        :return: The lifecycle_details of this VirtualService.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this VirtualService.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.


        :param lifecycle_details: The lifecycle_details of this VirtualService.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this VirtualService.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this VirtualService.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this VirtualService.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this VirtualService.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this VirtualService.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this VirtualService.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this VirtualService.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this VirtualService.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this VirtualService.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this VirtualService.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this VirtualService.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this VirtualService.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Schema(object):
    """
    The schema object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Schema object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Schema.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this Schema.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this Schema.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this Schema.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param name:
            The value to assign to the name property of this Schema.
        :type name: str

        :param resource_name:
            The value to assign to the resource_name property of this Schema.
        :type resource_name: str

        :param description:
            The value to assign to the description property of this Schema.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Schema.
        :type object_version: int

        :param external_key:
            The value to assign to the external_key property of this Schema.
        :type external_key: str

        :param is_has_containers:
            The value to assign to the is_has_containers property of this Schema.
        :type is_has_containers: bool

        :param default_connection:
            The value to assign to the default_connection property of this Schema.
        :type default_connection: str

        :param object_status:
            The value to assign to the object_status property of this Schema.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Schema.
        :type identifier: str

        :param metadata:
            The value to assign to the metadata property of this Schema.
        :type metadata: oci.data_connectivity.models.ObjectMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'resource_name': 'str',
            'description': 'str',
            'object_version': 'int',
            'external_key': 'str',
            'is_has_containers': 'bool',
            'default_connection': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'resource_name': 'resourceName',
            'description': 'description',
            'object_version': 'objectVersion',
            'external_key': 'externalKey',
            'is_has_containers': 'isHasContainers',
            'default_connection': 'defaultConnection',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'metadata': 'metadata'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._resource_name = None
        self._description = None
        self._object_version = None
        self._external_key = None
        self._is_has_containers = None
        self._default_connection = None
        self._object_status = None
        self._identifier = None
        self._metadata = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this Schema.
        The object key.


        :return: The key of this Schema.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Schema.
        The object key.


        :param key: The key of this Schema.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this Schema.
        The object's type.


        :return: The model_type of this Schema.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this Schema.
        The object's type.


        :param model_type: The model_type of this Schema.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this Schema.
        The object's model version.


        :return: The model_version of this Schema.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this Schema.
        The object's model version.


        :param model_version: The model_version of this Schema.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this Schema.

        :return: The parent_ref of this Schema.
        :rtype: oci.data_connectivity.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this Schema.

        :param parent_ref: The parent_ref of this Schema.
        :type: oci.data_connectivity.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Schema.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this Schema.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Schema.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this Schema.
        :type: str
        """
        self._name = name

    @property
    def resource_name(self):
        """
        Gets the resource_name of this Schema.
        A resource name can have letters, numbers, and special characters. The value is editable and is restricted to 4000 characters.


        :return: The resource_name of this Schema.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this Schema.
        A resource name can have letters, numbers, and special characters. The value is editable and is restricted to 4000 characters.


        :param resource_name: The resource_name of this Schema.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def description(self):
        """
        Gets the description of this Schema.
        User-defined description for the schema.


        :return: The description of this Schema.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Schema.
        User-defined description for the schema.


        :param description: The description of this Schema.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this Schema.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this Schema.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this Schema.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this Schema.
        :type: int
        """
        self._object_version = object_version

    @property
    def external_key(self):
        """
        Gets the external_key of this Schema.
        The external key for the object.


        :return: The external_key of this Schema.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this Schema.
        The external key for the object.


        :param external_key: The external_key of this Schema.
        :type: str
        """
        self._external_key = external_key

    @property
    def is_has_containers(self):
        """
        Gets the is_has_containers of this Schema.
        Specifies whether the schema has containers.


        :return: The is_has_containers of this Schema.
        :rtype: bool
        """
        return self._is_has_containers

    @is_has_containers.setter
    def is_has_containers(self, is_has_containers):
        """
        Sets the is_has_containers of this Schema.
        Specifies whether the schema has containers.


        :param is_has_containers: The is_has_containers of this Schema.
        :type: bool
        """
        self._is_has_containers = is_has_containers

    @property
    def default_connection(self):
        """
        Gets the default_connection of this Schema.
        The default connection key.


        :return: The default_connection of this Schema.
        :rtype: str
        """
        return self._default_connection

    @default_connection.setter
    def default_connection(self, default_connection):
        """
        Sets the default_connection of this Schema.
        The default connection key.


        :param default_connection: The default_connection of this Schema.
        :type: str
        """
        self._default_connection = default_connection

    @property
    def object_status(self):
        """
        Gets the object_status of this Schema.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this Schema.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this Schema.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this Schema.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this Schema.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this Schema.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this Schema.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this Schema.
        :type: str
        """
        self._identifier = identifier

    @property
    def metadata(self):
        """
        Gets the metadata of this Schema.

        :return: The metadata of this Schema.
        :rtype: oci.data_connectivity.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this Schema.

        :param metadata: The metadata of this Schema.
        :type: oci.data_connectivity.models.ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
